/* TabFileEvaluator.java */
package sample;

import java.util.*;
import java.io.*;

// R|lg
class TSPLoader implements Result<Map<String, String>> {
  /* -- component ports */
  // @Provide
  public final Result<Map<String, String>>  result;
  // @Require
  public void setInput(Reader reader) {
    input = new BufferedReader(reader);
  }
  /* -- end ports */

  public TSPLoader() {
    result = this;
  }

  private BufferedReader input;  
  private Map<String, String> map;
  private boolean available = false;
  
  public void load() throws IOException {
    
    map = new HashMap<String, String>();
    available = false;

    String line;
    while ((line = input.readLine()) != null) {
      Scanner sc = new Scanner(new StringReader(line));
      sc.useDelimiter("\\t+");
      String first = sc.next();
      String second = sc.next();
      map.put(first, second);
    }
    available = true;
  }
  public boolean isAvailable() {
    return available;
  }
  public Map<String, String> result() {
    return map;
  }
}

public class TabFileEvaluator implements Evaluator {

  private Map<String, String> map = new HashMap<String, String>();

  public void load(String file) throws IOException {
    TSPLoader loader = new TSPLoader();
    Reader reader = new FileReader(new File(file));
    loader.setInput(reader);
    loader.load();
    if (loader.result.isAvailable()) {
      map = loader.result.result();
    } else {
      map = new HashMap<String, String>();
    }
  }
  
  public String eval(String arg) {
    return map.get(arg);
  }
}
