/* VSTMainCmp.java */
package sample;

import java.io.*;
import java.util.*;
import sample.model.*;

public class VSTMainCmp implements Startable {
  /* -- component ports */

  // @Provide
  public final Startable starter;

  // @Require(Occurence.OPTIONAL)
  public String inputName = null;
  // @Require(Occurence.OPTIONAL)
  public String outputName = null;
  // @Require
  public Evaluator evaluator;
  // @Require
  public ExitReportHandler reportHandler;

  /* -- end ports */

  public VSTMainCmp() {
    starter = this;
  }

  public void start() throws CannotStartException {
    /* ========== iK ========== */
    // input̏
    Reader input = null;
    if (inputName  == null) {
      input = new InputStreamReader(System.in);
    } else {
      try {
        input = new FileReader(inputName);
      } catch (Exception e) {
        reportHandler.aborted(1, e.toString(), e);
        return;
      }
    }
    // parseȑ
    VSTParserPI parser;
    // result̏
    Result<List<Node>> result;
    // 
    VSTLexerCmp lexerCmp = new VSTLexerCmp();
    VSTParserCmp parserCmp = new VSTParserCmp();
    ModelBuilder builder = new ModelBuilder();
    // CO
    lexerCmp.setInput(input);
    parserCmp.lexer = lexerCmp.lexer;
    parserCmp.handler = builder.handler;
    parser = parserCmp.parser;
    result = builder.result;
    // s
    try {
      parser.parse();
    } catch (Exception e) {
      reportHandler.aborted(1, e.toString(), e);
      return;
    }
    // ʎ擾
    if (!result.isAvailable()) {
      reportHandler.aborted(1, "Unknown error.", null);
      return;
    }
    List<Node> model = null;
    try {
      model = result.result();
    } catch (Exception e) {
      reportHandler.aborted(1, e.toString(), e);
      return;
    }

    /* ========== iK ========== */
    // output̏
    PrintStream output = null;
    if (outputName == null) {
      output = System.out;
    } else {
      try {
        output = new PrintStream(new File(outputName));
      } catch (Exception e) {
	reportHandler.aborted(1, e.toString(), e);
	return;
      }
    }
    // processoȑ
    VSTProcessorPI processor;
    // 
    VSTProcessorCmp processorCmp = new VSTProcessorCmp();
    // CO
    processorCmp.model = model;
    processorCmp.evaluator  = evaluator;
    processorCmp.setOutput(output);
    processor = processorCmp.processor;
    // s
    try {
      processor.process();
    } catch (Exception e) {
      reportHandler.aborted(1, e.toString(), e);
      return;
    }
    // n
    try {
      input.close();
      output.close();
    } catch (Exception e) {
      throw new RuntimeException(e);
    }
    reportHandler.finished(0);
    return;
  }
}
