/* ModelBuilder.java */
package sample.model;

import java.util.*;
import sample.VSTHandler;
import sample.Result;

public class ModelBuilder implements VSTHandler, Result<List<Node>> {
  /* -- component ports */
  // @Provide
  public final VSTHandler handler;
  // @Provide
  public final Result<List<Node>> result;
  /* -- end ports */

  public ModelBuilder() {
    handler = this;
    result = this;
  }

  private List<Node> list = null;
  private boolean available = false;

  public void startTemplate() {
    list = new LinkedList<Node>();
  }
    
  public void endTemplate() {
    available = true;
  }

  public void placeholder(String content) {
    list.add(new PlaceholderNode(content));
  }

  public void text(String text) {
    list.add(new TextNode(text));
  }

  public void error(String message) {
    list = null;
    available = false;
  }

  public List<Node> result() {
    return list;
  }

  public boolean isAvailable() {
    return available;
  }
}
